@@ -57,7 +57,7 @@ struct _BjbNoteViewPrivate {
 
 static void on_window_closed(GtkWidget *window,gpointer note);
 static gboolean on_note_trashed (BijiNoteObj *note, BjbNoteView *view);
-
+static void on_note_color_changed_cb (BijiNoteObj *note, BjbNoteView *self);
 
 static void
 bjb_note_view_disconnect (BjbNoteView *self)
@@ -67,6 +67,7 @@ bjb_note_view_disconnect (BjbNoteView *self)
   priv = self->priv;
   g_signal_handlers_disconnect_by_func (priv->window, on_window_closed, priv->note);
   g_signal_handlers_disconnect_by_func (priv->note, on_note_trashed, self);
+  g_signal_handlers_disconnect_by_func (priv->note, on_note_color_changed_cb, self);
 }
 
 
@@ -176,7 +177,7 @@ on_note_color_changed_cb (BijiNoteObj *note, BjbNoteView *self)
 
   g_return_if_fail (BIJI_IS_NOTE_OBJ (note));
 
-  biji_note_obj_get_rgba (priv->note, &color);
+  biji_note_obj_get_rgba (note, &color);
   if (color.red < 0.5)
     font_color = "white";
   else
@@ -189,7 +190,7 @@ on_note_color_changed_cb (BijiNoteObj *note, BjbNoteView *self)
    */
   text = g_strdup_printf (_("<b>Last updated</b> %s"),
                           biji_note_obj_get_last_change_date_string
-			            (priv->note));
+			            (note));
   span = g_strdup_printf ("<span color='%s'>%s</span>", font_color, text);
   gtk_label_set_markup (GTK_LABEL (priv->last_update), span);
 
