@@ -270,7 +270,7 @@ biji_note_id_get_mtime (BijiNoteID *n)
 gboolean
 biji_note_id_set_mtime (BijiNoteID *n, gint64 time)
 {
-  g_return_if_fail (BIJI_IS_NOTE_ID (n));
+  g_return_val_if_fail (BIJI_IS_NOTE_ID (n), FALSE);
 
   if (n->priv->mtime != time)
   {
