@@ -45,6 +45,7 @@ struct _BijiWebkitEditorPrivate
   BijiNoteObj *note;
   gulong content_changed;
   gulong color_changed;
+  gchar *font_color;
 
   WebKitWebSettings *settings;
   EEditorSelection *sel;
@@ -198,32 +199,26 @@ biji_webkit_editor_init (BijiWebkitEditor *self)
 {
   WebKitWebView *view = WEBKIT_WEB_VIEW (self);
   BijiWebkitEditorPrivate *priv;
-  gchar *css_path;
 
   priv = G_TYPE_INSTANCE_GET_PRIVATE (self, BIJI_TYPE_WEBKIT_EDITOR, BijiWebkitEditorPrivate);
   self->priv = priv;
 
   priv->sel = e_editor_selection_new (view);
+  priv->font_color = NULL;
 
   /* Settings */
   webkit_web_view_set_editable (view, TRUE);
   webkit_web_view_set_transparent (view, TRUE);
   priv->settings = webkit_web_view_get_settings (view);
 
-  css_path = g_build_filename ("file://",
-                               DATADIR, "bijiben",
-                               "Default.css",NULL);
 
   g_object_set (G_OBJECT(priv->settings),
                 "enable-plugins", FALSE,
                 "enable-file-access-from-file-uris", TRUE,
-                "user-stylesheet-uri", css_path,
                 "enable-spell-checking", TRUE,
                 "tab-key-cycles-through-elements", FALSE,
                 NULL);
 
-  g_free (css_path);
-
   priv->spell_check = webkit_get_text_checker ();
 }
 
@@ -236,6 +231,7 @@ biji_webkit_editor_finalize (GObject *object)
   /* priv->spell_check is ref by webkit. probably not to unref */
   g_object_unref (priv->sel);
 
+  g_free (priv->font_color);
 
   if (priv->note != NULL)
     g_signal_handler_disconnect (priv->note, priv->color_changed);
@@ -295,6 +291,131 @@ on_content_changed (WebKitWebView *view)
   biji_note_obj_save_note (note);
 }
 
+
+static void
+on_css_directory_created (GObject *source,
+                          GAsyncResult *res,
+                          gpointer user_data)
+{
+  BijiWebkitEditorPrivate *priv;
+  gchar *path_src = NULL, *path_dest = NULL, *css_path = NULL, *font_color = NULL, *css = NULL;
+  GFile *src = NULL, *dest = NULL;
+  GdkRGBA color;
+  GError *error = NULL;
+  GFileInputStream *str;
+  gchar buffer[1000] = "";
+  gsize bytes;
+  GRegex *rgxp = NULL;
+
+  priv = BIJI_WEBKIT_EDITOR (user_data)->priv;
+  biji_note_obj_get_rgba (priv->note,&color);
+
+  /*
+   * Generate font color
+   * See if need need to change css.
+   */
+  if (color.red < 0.5)
+    font_color = "white";
+  else
+    font_color = "black";
+
+  if (g_strcmp0 (priv->font_color, font_color) == 0)
+    return;
+  else
+    priv->font_color = g_strdup (font_color);
+
+
+  /* build the path for source and Destination of Default.css */
+  path_src = g_build_filename(DATADIR, "bijiben", "Default.css", NULL);
+  src = g_file_new_for_path (path_src);
+
+  path_dest = g_build_filename(g_get_tmp_dir (), "bijiben", "Default.css", NULL);
+  dest = g_file_new_for_path (path_dest);
+  css_path = g_file_get_uri (dest);
+
+  /* Read & amend the css */
+  str = g_file_read (src, NULL, &error);
+
+  if (error)
+  {
+    g_warning ("%s", error->message);
+    g_error_free (error);
+    goto out;
+  }
+
+  g_input_stream_read_all (G_INPUT_STREAM (str), buffer, 1000, &bytes, NULL, &error);
+
+  if (error)
+  {
+    g_warning ("%s", error->message);
+    g_error_free (error);
+    goto out;
+  }
+
+  g_input_stream_close (G_INPUT_STREAM (str), NULL, NULL);
+  rgxp = g_regex_new ("_BIJI_TEXT_COLOR", 0, 0, NULL);
+  css = g_regex_replace_literal (rgxp, buffer, -1, 0, priv->font_color, 0, &error);
+
+  if (error)
+  {
+    g_warning ("%s", error->message);
+    g_error_free (error);
+    goto out;
+  }
+
+  /* copy the Default.css file */
+  g_file_replace_contents (dest, css, 1000, NULL, FALSE, G_FILE_CREATE_NONE, NULL, NULL, &error);
+
+  if (error)
+  {
+    g_warning ("%s", error->message);
+    g_error_free (error);
+    goto out;
+  }
+
+  /* Change the css path to NULL and then
+     again set it back to actual css path
+     so that changes in css file are considered
+     immediately */
+
+  g_object_set (G_OBJECT(priv->settings),
+               "user-stylesheet-uri", NULL,
+               NULL);
+
+  g_object_set (G_OBJECT(priv->settings),
+                "user-stylesheet-uri", css_path,
+                NULL);
+
+out:
+  g_object_unref (str);
+  g_free (css_path);
+  g_free (path_src);
+  g_free (path_dest);
+  g_object_unref (src);
+  g_object_unref (dest);
+  g_free (css);
+  g_regex_unref (rgxp);
+}
+
+static void
+biji_webkit_editor_change_css_file(BijiWebkitEditor *self)
+{
+  gchar *bijiben_temp_dir_path;
+  GFile *bijiben_temp_dir;
+
+  /* Generate Temp directory path and URI for bijiben */
+  bijiben_temp_dir_path = g_build_filename (g_get_tmp_dir (), "bijiben", NULL);
+  bijiben_temp_dir = g_file_new_for_path (bijiben_temp_dir_path);
+  g_file_make_directory (bijiben_temp_dir, NULL, NULL);
+
+  g_file_make_directory_async (bijiben_temp_dir,
+                               G_PRIORITY_DEFAULT,
+                               NULL, /* cancellable */
+                               on_css_directory_created,
+                               self);
+}
+
+
 static void
 on_note_color_changed (BijiNoteObj *note, BijiWebkitEditor *self)
 {
@@ -464,30 +585,3 @@ biji_webkit_editor_new (BijiNoteObj *note)
                        "note", note,
                        NULL);
 }
-
-void
-biji_webkit_editor_change_css_file(BijiWebkitEditor *self)
-{
-  BijiWebkitEditorPrivate *priv;
-  gchar *css_path;
-  GdkRGBA color;
-
-  priv = G_TYPE_INSTANCE_GET_PRIVATE (self, BIJI_TYPE_WEBKIT_EDITOR, BijiWebkitEditorPrivate);
-
-  biji_note_obj_get_rgba(priv->note,&color);
-
-  if(color.red < 0.5)
-    css_path = g_build_filename ("file://",
-				 DATADIR, "bijiben",
-				 "Default-white.css",NULL);
-  else
-    css_path = g_build_filename ("file://",
-				 DATADIR, "bijiben",
-				 "Default-black.css",NULL);
-
-  g_object_set (G_OBJECT(priv->settings),
-    "user-stylesheet-uri", css_path, NULL);
-
-  g_free (css_path);
-  return;
-}
